==> zio-aws-sesv2_3-5.17.116.2-sources.jar: zio/aws/sesv2/model/PutAccountDedicatedIpWarmupAttributesRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.Enabled
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class PutAccountDedicatedIpWarmupAttributesRequest(
    autoWarmupEnabled: Option[Enabled] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest = {
    import PutAccountDedicatedIpWarmupAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
      .builder()
      .optionallyWith(
        autoWarmupEnabled.map(value => Enabled.unwrap(value): java.lang.Boolean)
      )(_.autoWarmupEnabled)
      .build()
  }
  def asReadOnly
      : zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly =
    zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
      .wrap(buildAwsValue())
}
object PutAccountDedicatedIpWarmupAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest =
      zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest(
        autoWarmupEnabled.map(value => value)
      )
    def autoWarmupEnabled: Option[Enabled]
    def getAutoWarmupEnabled: ZIO[Any, AwsError, Enabled] =
      AwsError.unwrapOptionField("autoWarmupEnabled", autoWarmupEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ) extends zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly {
    override val autoWarmupEnabled: Option[Enabled] = scala
      .Option(impl.autoWarmupEnabled())
      .map(value => zio.aws.sesv2.model.primitives.Enabled(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ): zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-sesv2_3-5.17.195.1-sources.jar: zio/aws/sesv2/model/PutAccountDedicatedIpWarmupAttributesRequest.scala <==
package zio.aws.sesv2.model
import zio.aws.sesv2.model.primitives.Enabled
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters.*
final case class PutAccountDedicatedIpWarmupAttributesRequest(
    autoWarmupEnabled: Optional[Enabled] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest = {
    import PutAccountDedicatedIpWarmupAttributesRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
      .builder()
      .optionallyWith(
        autoWarmupEnabled.map(value => Enabled.unwrap(value): java.lang.Boolean)
      )(_.autoWarmupEnabled)
      .build()
  }
  def asReadOnly
      : zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly =
    zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
      .wrap(buildAwsValue())
}
object PutAccountDedicatedIpWarmupAttributesRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest =
      zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest(
        autoWarmupEnabled.map(value => value)
      )
    def autoWarmupEnabled: Optional[Enabled]
    def getAutoWarmupEnabled: ZIO[Any, AwsError, Enabled] =
      AwsError.unwrapOptionField("autoWarmupEnabled", autoWarmupEnabled)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ) extends zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly {
    override val autoWarmupEnabled: Optional[Enabled] = zio.aws.core.internal
      .optionalFromNullable(impl.autoWarmupEnabled())
      .map(value => zio.aws.sesv2.model.primitives.Enabled(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest
  ): zio.aws.sesv2.model.PutAccountDedicatedIpWarmupAttributesRequest.ReadOnly =
    new Wrapper(impl)
}
